pub struct ResponseError {
pub code: i32,
pub message: String,
pub data: Option<Value>,
}Expand description
LSP ResponseError as defined by the JSON-RPC specification. This corresponds to the error object in LSP response messages.
Fields
code: i32A number indicating the error type that occurred.
message: StringA string providing a short description of the error.
data: Option<Value>A primitive or structured value that contains additional information about the error.
Implementations
Sourceimpl ResponseError
impl ResponseError
Sourcepub fn new(code: i32, message: impl Into<String>) -> Self
pub fn new(code: i32, message: impl Into<String>) -> Self
Create a new ResponseError with the given code and message.
Sourcepub fn with_data(code: i32, message: impl Into<String>, data: Value) -> Self
pub fn with_data(code: i32, message: impl Into<String>, data: Value) -> Self
Create a new ResponseError with additional data.
Sourcepub fn parse_error(message: impl Into<String>) -> Self
pub fn parse_error(message: impl Into<String>) -> Self
Create a parse error.
Sourcepub fn invalid_request(message: impl Into<String>) -> Self
pub fn invalid_request(message: impl Into<String>) -> Self
Create an invalid request error.
Sourcepub fn method_not_found(message: impl Into<String>) -> Self
pub fn method_not_found(message: impl Into<String>) -> Self
Create a method not found error.
Sourcepub fn invalid_params(message: impl Into<String>) -> Self
pub fn invalid_params(message: impl Into<String>) -> Self
Create an invalid params error.
Sourcepub fn internal_error(message: impl Into<String>) -> Self
pub fn internal_error(message: impl Into<String>) -> Self
Create an internal error.
Sourcepub fn server_not_initialized(message: impl Into<String>) -> Self
pub fn server_not_initialized(message: impl Into<String>) -> Self
Create a server not initialized error.
Sourcepub fn request_cancelled(message: impl Into<String>) -> Self
pub fn request_cancelled(message: impl Into<String>) -> Self
Create a request cancelled error.
Sourcepub fn content_modified(message: impl Into<String>) -> Self
pub fn content_modified(message: impl Into<String>) -> Self
Create a content modified error.