pub struct CompletionOptions {
pub resolve_provider: Option<bool>,
pub trigger_characters: Option<Vec<String>>,
pub all_commit_characters: Option<Vec<String>>,
}Expand description
Completion options.
Fields
resolve_provider: Option<bool>The server provides support to resolve additional information for a completion item.
trigger_characters: Option<Vec<String>>Most tools trigger completion request automatically without explicitly requesting it using a keyboard shortcut (e.g. Ctrl+Space).
all_commit_characters: Option<Vec<String>>The list of all possible characters that commit a completion.